%define upstream_name    Games-FrozenBubble
%define upstream_version 2.212

Name:		frozen-bubble
Version:	%perl_convert_version %{upstream_version}
Release:	%mkrel 40

Summary:	Frozen Bubble arcade game
License:	GPLv2+
Group:		Games/Arcade
Url:		http://www.frozen-bubble.org/
Source0:	http://www.frozen-bubble.org/data/%{upstream_name}-%{upstream_version}.tar.gz
Patch0:		frozen-bubble-2.2.1-setuid.patch
Patch1:		0001-Fix-buffer-size-when-formatting-current-date.patch
Patch2:		frozen-bubble-2.2.1-Use-true-number-instead-of-quoted-version-number.patch

BuildRequires:	glib2-devel
BuildRequires:	perl(Alien::SDL)
BuildRequires:	perl(Archive::Extract)
BuildRequires:	perl(autodie)
BuildRequires:	perl(Compress::Bzip2)
BuildRequires:	perl(IPC::System::Simple)
BuildRequires:	perl(Locale::Maketext::Extract)
BuildRequires:	perl(parent)
BuildRequires:	perl(SDL) >= 2.400.0
BuildRequires:	perl-devel
BuildRequires:	pkgconfig(SDL_image)
BuildRequires:	pkgconfig(SDL_mixer) >= 1.2.2
BuildRequires:	pkgconfig(SDL_Pango)
BuildRequires:	smpeg-devel

Requires:	perl-SDL >= 2.400.0
Obsoletes:	frozen-bubble-server-common < 2.212

%description
A Puzzle Bobble / Bust-a-Move like game featuring colorful 3D rendered
penguin animations, 100 levels, local and Internet-based multiplayer,
a level editor, 3 professional quality digital soundtracks, 15 stereo
sound effects, 8 unique graphical transition effects, 8 unique logo
eye-candies.

%prep
%autosetup -p1 -n %{upstream_name}-%{upstream_version}

%build
export CFLAGS="%{optflags} -Wno-error=unused-result"
%{__perl} Build.PL installdirs=vendor
# Remove invalid rpaths
sed -i "/-Wl,-rpath/d" _build/build_params
./Build --perl=%{__perl}

%install
./Build install --perl=%{__perl} destdir=%{buildroot}
rm -f %{buildroot}%{_gamesdatadir}/frozen-bubble/gfx/shoot/create.pl

install -d -m 755 %{buildroot}%{_datadir}/applications
cat >  %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Frozen Bubble
Comment=Frozen Bubble arcade game
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=false
Categories=Game;ArcadeGame;
EOF

for size in 16x16 32x32 48x48; do
  install -D -m 644 share/icons/frozen-bubble-icon-${size}.png \
      %{buildroot}%{_iconsdir}/hicolor/${size}/apps/%{name}.png
done

%check
./Build  --perl=%{__perl} test

%files
%doc README AUTHORS META.yml HISTORY
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}-editor
%{_bindir}/fb-server
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}-editor.1*
%{_mandir}/man3/Games::FrozenBubble*.3pm*
%{perl_vendorarch}/auto/Games/FrozenBubble/
%{perl_vendorarch}/auto/share/dist/%{upstream_name}/
%{perl_vendorarch}/Games/FrozenBubble*


%changelog
* Sun Feb 16 2025 daviddavid <daviddavid> 2.212.0-40.mga10
+ Revision: 2149061
- add build patch from fedora

* Thu Aug 04 2022 tv <tv> 2.212.0-39.mga9
+ Revision: 1875068
- Rebuild for perl-5.36

* Sat Apr 02 2022 umeabot <umeabot> 2.212.0-38.mga9
+ Revision: 1840485
- Mageia 9 Mass Rebuild

* Wed Nov 24 2021 akien <akien> 2.212.0-37.mga9
+ Revision: 1759070
- Rebuild for new perl libs (mga#29687), and remove rpaths rpmbuild complains about

* Sat Mar 27 2021 eatdirt <eatdirt> 2.212.0-36.mga9
+ Revision: 1710949
- Rebuild for bug #28529

* Thu Feb 13 2020 umeabot <umeabot> 2.212.0-35.mga8
+ Revision: 1512334
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 2.212.0-34.mga7
+ Revision: 1297789
- Mageia 7 Mass Rebuild

* Sun Aug 12 2018 akien <akien> 2.212.0-33.mga7
+ Revision: 1251109
- Add Fedora patch to fix FTBFS with GCC 8
- Add Fedora patch to fix warning with unused result
+ tv <tv>
- rebuild for perl-5.28

* Mon Sep 25 2017 tv <tv> 2.212.0-31.mga7
+ Revision: 1159099
- rebuild with perl-5.26.x

* Wed Jul 20 2016 neoclust <neoclust> 2.212.0-30.mga6
+ Revision: 1042945
- Rebuild on arm
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 21 2015 tv <tv> 2.212.0-28.mga6
+ Revision: 893328
+ rebuild (emptylog)

* Wed Oct 14 2015 danf <danf> 2.212.0-27.mga6
+ Revision: 891684
- Removed empty lang file

* Thu Jun 25 2015 tv <tv> 2.212.0-26.mga6
+ Revision: 843588
- rebuild with soname-ified perl

* Tue Jun 23 2015 sander85 <sander85> 2.212.0-25.mga6
+ Revision: 840596
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 2.212.0-24.mga5
+ Revision: 742832
- Second Mageia 5 Mass Rebuild

* Mon Oct 06 2014 anaselli <anaselli> 2.212.0-23.mga5
+ Revision: 737054
- fix mga#14197 (hardcoded Perl version causes fail)

* Sat Sep 27 2014 tv <tv> 2.212.0-22.mga5
+ Revision: 726249
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.212.0-21.mga5
+ Revision: 679363
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 2.212.0-20.mga5
+ Revision: 632137
- perl 5.20.0 rebuild

* Thu Mar 20 2014 jquelin <jquelin> 2.212.0-19.mga5
+ Revision: 606046
- perl 5.18.2 rebuild

* Sat Feb 22 2014 eatdirt <eatdirt> 2.212.0-18.mga5
+ Revision: 595592
- Rebuild for new perl

* Sat Oct 19 2013 umeabot <umeabot> 2.212.0-17.mga4
+ Revision: 524140
- Mageia 4 Mass Rebuild

* Wed May 29 2013 tv <tv> 2.212.0-16.mga4
+ Revision: 430248
- rebuild for new perl

* Mon Mar 18 2013 jquelin <jquelin> 2.212.0-15.mga3
+ Revision: 403805
- perl 5.16.3 rebuild

* Fri Jan 11 2013 umeabot <umeabot> 2.212.0-14.mga3
+ Revision: 350964
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 luigiwalser <luigiwalser> 2.212.0-13.mga3
+ Revision: 340531
- kill compiler error

* Mon Nov 19 2012 sander85 <sander85> 2.212.0-12.mga3
+ Revision: 319603
- fix BR
+ jquelin <jquelin>
- perl 5.16.2 shebang rebuild

* Thu Aug 30 2012 tv <tv> 2.212.0-11.mga3
+ Revision: 285887
- rebuild for new perl

* Wed May 30 2012 jquelin <jquelin> 2.212.0-10.mga3
+ Revision: 250933
- rebuild for perl 5.16
- rebuild for perl 5.16
- rebuild for perl 5.16
- rebuild for perl 5.16

* Fri Oct 14 2011 jquelin <jquelin> 2.212.0-6.mga2
+ Revision: 155125
- perl 5.14.2 rebuild

* Sun Jun 19 2011 jquelin <jquelin> 2.212.0-5.mga2
+ Revision: 109878
- rebuild script for perl 5.14.1

* Sat Jun 11 2011 sander85 <sander85> 2.212.0-4.mga2
+ Revision: 103962
- perl 5.14

* Sun Apr 03 2011 stormi <stormi> 2.212.0-3.mga1
+ Revision: 79898
- obsolete frozen-bubble-server-common, no longer required and no longer provided in the distribution, so that it's uninstalled during upgrade

* Fri Feb 25 2011 ennael <ennael> 2.212.0-2.mga1
+ Revision: 60006
- clean spec file
- imported package frozen-bubble


* Wed Oct 20 2010 Jani Välimaa <wally@mandriva.org> 2.212.0-2mdv2011.0
+ Revision: 586981
- fix .desktop file

* Fri Sep 03 2010 Jérôme Quelin <jquelin@mandriva.org> 2.212.0-1mdv2011.0
+ Revision: 575580
- adding missing buildrequires:
- adding missing buildrequires:
- update to 2.212

* Sun Aug 01 2010 Funda Wang <fwang@mandriva.org> 2.2.0-5mdv2011.0
+ Revision: 564235
- rebuild for perl 5.12.1

* Thu Jul 22 2010 Funda Wang <fwang@mandriva.org> 2.2.0-4mdv2011.0
+ Revision: 556962
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 2.2.0-3mdv2010.1
+ Revision: 522672
- rebuilt for 2010.1

* Sun Aug 23 2009 Michael Scherer <misc@mandriva.org> 2.2.0-2mdv2010.0
+ Revision: 420214
- fix bug 52945, some constants are no longer exported with latest perl-SDL

* Fri Dec 12 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.2.0-1mdv2009.1
+ Revision: 313696
- export %%_prefix
- update to new version 2.2.0
- add buildrequires on libSDL_image-devel
- fix mixture of tabs and spaces
- use macros
- spec file clean

* Thu Jun 12 2008 Pixel <pixel@mandriva.com> 2.1.0-7mdv2009.0
+ Revision: 218423
- rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Mon Jan 14 2008 Thierry Vignaud <tv@mandriva.org> 2.1.0-7mdv2008.1
+ Revision: 151781
- rebuild
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Sep 19 2007 Adam Williamson <awilliamson@mandriva.org> 2.1.0-5mdv2008.0
+ Revision: 91113
- don't package license
- fd.o icons
- improve description
- new license policy

* Sun Sep 09 2007 David Walluck <walluck@mandriva.org> 2.1.0-4mdv2008.0
+ Revision: 83394
- rebuild (package was unsigned)

* Sun Sep 09 2007 Emmanuel Andry <eandry@mandriva.org> 2.1.0-3mdv2008.0
+ Revision: 83323
- Drop old menu

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'


* Fri Dec 01 2006 Thierry Vignaud <tvignaud@mandriva.com> 2.1.0-2mdv2007.0
+ Revision: 89694
- release
- fix upgrade (#27435)

* Fri Nov 24 2006 Thierry Vignaud <tvignaud@mandriva.com> 2.1.0-1mdv2007.1
+ Revision: 87021
- new release
- new source URL
- fix source url

  + Michael Scherer <misc@mandriva.org>
    - split server from main package, to host a server without pulling the whole set of deps

* Wed Nov 01 2006 Michael Scherer <misc@mandriva.org> 2.0.0-1mdv2007.1
+ Revision: 74955
- version 2.0, specfile merged from upstream with mandriva one
- fix bug #7778
- Import frozen-bubble

* Mon Sep 04 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.0.0-11mdv2007.0
- Really migrate to xdg menu

* Fri Jul 28 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.0-10mdv2007.0
- xdg menu
- spec cleanup

* Tue Mar 28 2006 Pixel <pixel@mandriva.com> 1.0.0-9mdk
- fix "make install" using DESTDIR
  (MakeMaker generated Makefile doesn't handle PREFIX anymore)

* Fri Dec 16 2005 Michael Scherer <misc@mandriva.org> 1.0.0-8mdk
- mkrel
- fix #20223 ( by simply rebuilding it, this is weird ).

* Mon Nov 15 2004 Guillaume Cottenceau <gc@mandrakesoft.com> 1.0.0-7mdk
- Rebuild for new perl

